@@ -4,7 +4,7 @@ from dataclasses import dataclass
 from typing import Any, Dict, List, Literal, Optional, TypedDict
 
 # Local Modules
-from cofactr.schema.types import Document
+from cofactr.schema.types import Document, TerminationType
 
 
 class Spec(TypedDict):
@@ -38,8 +38,9 @@ class Part:  # pylint: disable=too-many-instance-attributes
     mfr: Optional[str]  # manufacturer name.
     msl: Optional[int]  # Num of hours until a bake is required.
     package: Optional[str]
-    specs: Dict[str, Spec]
+    specs: List[Dict[Literal["id", "label", "value"], str]]
     terminations: Optional[int]
+    termination_type: TerminationType
 
     updated_at: Optional[str]
 
